@@ -40,9 +40,15 @@ class AutoReloadPlugin(object):
                 pass
     
     def on_start(self):
-        log("auto reloader start")
+        log("start auto reloader")
         self.reloader_run(self.main_loop, self.reloader_loop)
 
+    def main_loop(self):
+        pass
+
+    def reloader_loop(self):
+        pass
+
     def on_reload(self):
         log("reload")
         self.require_reload = True
@@ -52,10 +58,5 @@ class AutoReloadPlugin(object):
         log("stop")
         thread.interrupt_main()
     
-    def main_loop(self):
-        pass
-
-    def reloader_loop(self):
-        pass
 
 
